@@ -15,7 +15,7 @@ describe 'openstack_extras::repo::redhat::redhat' do
 
     let :paramclass_defaults do
       {
-        :release        => 'rocky',
+        :release        => 'stein',
         :repo_defaults  => { 'enabled' => '1',
                              'gpgcheck' => '1',
                              'notify' => 'Exec[yum_refresh]',
@@ -40,8 +40,8 @@ describe 'openstack_extras::repo::redhat::redhat' do
       end
 
       it { should contain_yumrepo('rdo-release').with(
-        :baseurl    => "http://mirror.centos.org/centos/7/cloud/$basearch/openstack-rocky/",
-        :descr      => 'OpenStack Rocky Repository',
+        :baseurl    => "http://mirror.centos.org/centos/7/cloud/$basearch/openstack-stein/",
+        :descr      => 'OpenStack Stein Repository',
         :gpgkey     => 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Cloud',
         :enabled    => '1',
         :gpgcheck   => '1',
@@ -180,8 +180,8 @@ describe 'openstack_extras::repo::redhat::redhat' do
       end
 
       it { should contain_yumrepo('rdo-release').with(
-        :baseurl => "http://mirror.dfw.rax.openstack.org/centos/7/cloud/\$basearch/openstack-rocky/",
-        :descr   => 'OpenStack Rocky Repository',
+        :baseurl => "http://mirror.dfw.rax.openstack.org/centos/7/cloud/\$basearch/openstack-stein/",
+        :descr   => 'OpenStack Stein Repository',
         :gpgkey  => 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Cloud',
         :proxy   => 'http://my.proxy.com:8000'
       )}
